@@ -16,6 +16,7 @@ EXTENSIONS = {
     'cc': {'text', 'c++'},
     'cu': {'text', 'cuda'},
     'cfg': {'text'},
+    'chs': {'text', 'c2hs'},
     'clj': {'text', 'clojure'},
     'cljc': {'text', 'clojure'},
     'cljs': {'text', 'clojure', 'clojurescript'},
@@ -44,6 +45,7 @@ EXTENSIONS = {
     'eyaml': {'text', 'yaml'},
     'feature': {'text', 'gherkin'},
     'fish': {'text', 'fish'},
+    'gd': {'text', 'gdscript'},
     'gemspec': {'text', 'ruby'},
     'gif': {'binary', 'image', 'gif'},
     'go': {'text', 'go'},
@@ -58,6 +60,7 @@ EXTENSIONS = {
     'gz': {'binary', 'gzip'},
     'h': {'text', 'header', 'c', 'c++'},
     'hpp': {'text', 'header', 'c++'},
+    'hs': {'text', 'haskell'},
     'htm': {'text', 'html'},
     'html': {'text', 'html'},
     'hxx': {'text', 'header', 'c++'},
@@ -68,6 +71,8 @@ EXTENSIONS = {
     'idr': {'text', 'idris'},
     'inc': {'text', 'inc'},
     'ini': {'text', 'ini'},
+    'inx': {'text', 'xml', 'inx'},
+    'ipynb': {'text', 'jupyter'},
     'j2': {'text', 'jinja'},
     'jade': {'text', 'jade'},
     'jar': {'binary', 'zip', 'jar'},
@@ -85,6 +90,8 @@ EXTENSIONS = {
     'kml': {'text', 'kml', 'xml'},
     'kt': {'text', 'kotlin'},
     'less': {'text', 'less'},
+    'lhs': {'text', 'literate-haskell'},
+    'libsonnet': {'text', 'jsonnet'},
     'lidr': {'text', 'idris'},
     'lua': {'text', 'lua'},
     'm': {'text', 'c', 'objective-c'},
@@ -92,6 +99,7 @@ EXTENSIONS = {
     'map': {'text', 'map'},
     'markdown': {'text', 'markdown'},
     'md': {'text', 'markdown'},
+    'mdx': {'text', 'mdx'},
     'mib': {'text', 'mib'},
     'mk': {'text', 'makefile'},
     'ml': {'text', 'ocaml'},
@@ -125,6 +133,8 @@ EXTENSIONS = {
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
     'pyx': {'text', 'cython'},
+    'pyz': {'binary', 'pyz'},
+    'pyzw': {'binary', 'pyz'},
     'pxd': {'text', 'cython'},
     'pxi': {'text', 'cython'},
     'r': {'text', 'r'},
@@ -145,7 +155,9 @@ EXTENSIONS = {
     'ss': {'text', 'scheme'},
     'styl': {'text', 'stylus'},
     'sql': {'text', 'sql'},
-    'svg': {'text', 'image', 'svg'},
+    'sv': {'text', 'system-verilog'},
+    'svg': {'text', 'image', 'svg', 'xml'},
+    'svh': {'text', 'system-verilog'},
     'swf': {'binary', 'swf'},
     'swift': {'text', 'swift'},
     'swiftdeps': {'text', 'swiftdeps'},
@@ -156,11 +168,15 @@ EXTENSIONS = {
     'tiff': {'binary', 'image', 'tiff'},
     'toml': {'text', 'toml'},
     'tf': {'text', 'terraform'},
+    'tfvars': {'text', 'terraform'},
     'ts': {'text', 'ts'},
     'tsx': {'text', 'tsx'},
     'ttf': {'binary', 'ttf'},
     'txt': {'text', 'plain-text'},
+    'v': {'text', 'verilog'},
     'vdx': {'text', 'vdx'},
+    'vh': {'text', 'verilog'},
+    'vhd': {'text', 'vhdl'},
     'vim': {'text', 'vim'},
     'vue': {'text', 'vue'},
     'war': {'binary', 'zip', 'jar'},
